Task1_mareev_meledin
====================

Info
----
This package was created to train the skills of publishing packages. Please do not download it if you do not know Mareev Gleb or Meledin Stanislav :)


Using
------

To use, simply do::

    import task1_mareev_meledin as ts
    print(ts.nash_equilibrium([[1, 2], [2, 3]]))

